@@ -169,6 +169,8 @@ __all__ = (
     "DescribeTransitGatewayConnectsPaginatorName",
     "DescribeTransitGatewayMulticastDomainsPaginatorName",
     "DescribeTransitGatewayPeeringAttachmentsPaginatorName",
+    "DescribeTransitGatewayPolicyTablesPaginatorName",
+    "DescribeTransitGatewayRouteTableAnnouncementsPaginatorName",
     "DescribeTransitGatewayRouteTablesPaginatorName",
     "DescribeTransitGatewayVpcAttachmentsPaginatorName",
     "DescribeTransitGatewaysPaginatorName",
@@ -193,6 +195,7 @@ __all__ = (
     "DnsRecordIpTypeType",
     "DnsSupportValueType",
     "DomainTypeType",
+    "DynamicRoutingValueType",
     "EbsEncryptionSupportType",
     "EbsNvmeSupportType",
     "EbsOptimizedSupportType",
@@ -239,6 +242,7 @@ __all__ = (
     "GetSpotPlacementScoresPaginatorName",
     "GetTransitGatewayAttachmentPropagationsPaginatorName",
     "GetTransitGatewayMulticastDomainAssociationsPaginatorName",
+    "GetTransitGatewayPolicyTableAssociationsPaginatorName",
     "GetTransitGatewayPrefixListReferencesPaginatorName",
     "GetTransitGatewayRouteTableAssociationsPaginatorName",
     "GetTransitGatewayRouteTablePropagationsPaginatorName",
@@ -380,6 +384,7 @@ __all__ = (
     "SpotInstanceRequestFulfilledWaiterName",
     "SpotInstanceStateType",
     "SpotInstanceTypeType",
+    "SpreadLevelType",
     "StateType",
     "StaticSourcesSupportValueType",
     "StatusNameType",
@@ -411,9 +416,12 @@ __all__ = (
     "TransitGatewayConnectPeerStateType",
     "TransitGatewayMulitcastDomainAssociationStateType",
     "TransitGatewayMulticastDomainStateType",
+    "TransitGatewayPolicyTableStateType",
     "TransitGatewayPrefixListReferenceStateType",
     "TransitGatewayPropagationStateType",
     "TransitGatewayRouteStateType",
+    "TransitGatewayRouteTableAnnouncementDirectionType",
+    "TransitGatewayRouteTableAnnouncementStateType",
     "TransitGatewayRouteTableStateType",
     "TransitGatewayRouteTypeType",
     "TransitGatewayStateType",
@@ -706,6 +714,10 @@ DescribeTransitGatewayMulticastDomainsPaginatorName = Literal[
 DescribeTransitGatewayPeeringAttachmentsPaginatorName = Literal[
     "describe_transit_gateway_peering_attachments"
 ]
+DescribeTransitGatewayPolicyTablesPaginatorName = Literal["describe_transit_gateway_policy_tables"]
+DescribeTransitGatewayRouteTableAnnouncementsPaginatorName = Literal[
+    "describe_transit_gateway_route_table_announcements"
+]
 DescribeTransitGatewayRouteTablesPaginatorName = Literal["describe_transit_gateway_route_tables"]
 DescribeTransitGatewayVpcAttachmentsPaginatorName = Literal[
     "describe_transit_gateway_vpc_attachments"
@@ -738,6 +750,7 @@ DnsNameStateType = Literal["failed", "pendingVerification", "verified"]
 DnsRecordIpTypeType = Literal["dualstack", "ipv4", "ipv6", "service-defined"]
 DnsSupportValueType = Literal["disable", "enable"]
 DomainTypeType = Literal["standard", "vpc"]
+DynamicRoutingValueType = Literal["disable", "enable"]
 EbsEncryptionSupportType = Literal["supported", "unsupported"]
 EbsNvmeSupportType = Literal["required", "supported", "unsupported"]
 EbsOptimizedSupportType = Literal["default", "supported", "unsupported"]
@@ -783,7 +796,9 @@ FleetStateCodeType = Literal[
     "submitted",
 ]
 FleetTypeType = Literal["instant", "maintain", "request"]
-FlowLogsResourceTypeType = Literal["NetworkInterface", "Subnet", "VPC"]
+FlowLogsResourceTypeType = Literal[
+    "NetworkInterface", "Subnet", "TransitGateway", "TransitGatewayAttachment", "VPC"
+]
 FpgaImageAttributeNameType = Literal["description", "loadPermission", "name", "productCodes"]
 FpgaImageStateCodeType = Literal["available", "failed", "pending", "unavailable"]
 GatewayAssociationStateType = Literal[
@@ -808,6 +823,9 @@ GetTransitGatewayAttachmentPropagationsPaginatorName = Literal[
 GetTransitGatewayMulticastDomainAssociationsPaginatorName = Literal[
     "get_transit_gateway_multicast_domain_associations"
 ]
+GetTransitGatewayPolicyTableAssociationsPaginatorName = Literal[
+    "get_transit_gateway_policy_table_associations"
+]
 GetTransitGatewayPrefixListReferencesPaginatorName = Literal[
     "get_transit_gateway_prefix_list_references"
 ]
@@ -1221,6 +1239,7 @@ InstanceTypeType = Literal[
     "m6i.metal",
     "m6i.xlarge",
     "mac1.metal",
+    "mac2.metal",
     "p2.16xlarge",
     "p2.8xlarge",
     "p2.xlarge",
@@ -1665,7 +1684,9 @@ ResourceTypeType = Literal[
     "transit-gateway-attachment",
     "transit-gateway-connect-peer",
     "transit-gateway-multicast-domain",
+    "transit-gateway-policy-table",
     "transit-gateway-route-table",
+    "transit-gateway-route-table-announcement",
     "volume",
     "vpc",
     "vpc-endpoint",
@@ -1702,6 +1723,7 @@ SpotInstanceInterruptionBehaviorType = Literal["hibernate", "stop", "terminate"]
 SpotInstanceRequestFulfilledWaiterName = Literal["spot_instance_request_fulfilled"]
 SpotInstanceStateType = Literal["active", "cancelled", "closed", "failed", "open"]
 SpotInstanceTypeType = Literal["one-time", "persistent"]
+SpreadLevelType = Literal["host", "rack"]
 StateType = Literal[
     "Available",
     "Deleted",
@@ -1784,11 +1806,16 @@ TransitGatewayMulitcastDomainAssociationStateType = Literal[
     "rejected",
 ]
 TransitGatewayMulticastDomainStateType = Literal["available", "deleted", "deleting", "pending"]
+TransitGatewayPolicyTableStateType = Literal["available", "deleted", "deleting", "pending"]
 TransitGatewayPrefixListReferenceStateType = Literal[
     "available", "deleting", "modifying", "pending"
 ]
 TransitGatewayPropagationStateType = Literal["disabled", "disabling", "enabled", "enabling"]
 TransitGatewayRouteStateType = Literal["active", "blackhole", "deleted", "deleting", "pending"]
+TransitGatewayRouteTableAnnouncementDirectionType = Literal["incoming", "outgoing"]
+TransitGatewayRouteTableAnnouncementStateType = Literal[
+    "available", "deleted", "deleting", "failed", "failing", "pending"
+]
 TransitGatewayRouteTableStateType = Literal["available", "deleted", "deleting", "pending"]
 TransitGatewayRouteTypeType = Literal["propagated", "static"]
 TransitGatewayStateType = Literal["available", "deleted", "deleting", "modifying", "pending"]
@@ -2082,12 +2109,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
-    "redshiftserverless",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -2252,6 +2280,8 @@ PaginatorName = Literal[
     "describe_transit_gateway_connects",
     "describe_transit_gateway_multicast_domains",
     "describe_transit_gateway_peering_attachments",
+    "describe_transit_gateway_policy_tables",
+    "describe_transit_gateway_route_table_announcements",
     "describe_transit_gateway_route_tables",
     "describe_transit_gateway_vpc_attachments",
     "describe_transit_gateways",
@@ -2280,6 +2310,7 @@ PaginatorName = Literal[
     "get_spot_placement_scores",
     "get_transit_gateway_attachment_propagations",
     "get_transit_gateway_multicast_domain_associations",
+    "get_transit_gateway_policy_table_associations",
     "get_transit_gateway_prefix_list_references",
     "get_transit_gateway_route_table_associations",
     "get_transit_gateway_route_table_propagations",
